@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use Carp;
 use Error qw(:try);
-use Module::Load;
+use Module::Load qw(load);
 use Locale::Country;
 
 use Date::Holidays::Exception::AdapterLoad;
@@ -15,7 +15,7 @@ use Date::Holidays::Exception::UnsupportedMethod;
 
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.16';
 
 sub new {
     my ($class, %params) = @_;
@@ -225,7 +225,7 @@ You can also inherit the one implemented and offered by this class
 B<NB>If inheritance is used, please remember to overwrite the two following
 methods, if applicable.
 
-=item * holidays
+=item holidays
 
 This has to follow the API outlined in SUBROUTINES/METHODS.
 
@@ -235,7 +235,7 @@ Please refer to the DEVELOPER section in L<Date::Holidays> about contributing to
 the Date::Holidays::* namespace or attempting for adaptability with
 L<Date::Holidays>.
 
-=item * is_holiday
+=item is_holiday
 
 This has to follow the API outlined in SUBROUTINES/METHODS.
 
